@@ -6,6 +6,13 @@ Config:
         Discord token for the bot user.
     bot (bool):
         Whether the token represents a bot user (true by default).
+    members (bool):
+        Whether to use the privileged members intent to retrieve per-server member information.
+        Without this, per-server nicknames will be unavailable.
+
+        Before enabling here, you must enable the intent in Discord's developer site, otherwise the
+        underlying client will fail to connect.  For bots in large numbers of servers, this may
+        cause a significantly longer startup time whilst members are initially retrieved.
     webhooks ((str, str) dict):
         Mapping from named Discord channels to webhook URLs, needed for custom message author names
         and avatars.
@@ -48,6 +55,7 @@ class _Schema:
 
     config = immp.Schema({"token": str,
                           immp.Optional("bot", True): bool,
+                          immp.Optional("members", False): bool,
                           immp.Optional("webhooks", dict): {str: str},
                           immp.Optional("playing"): immp.Nullable(str)})
 
@@ -81,14 +89,16 @@ class DiscordUser(immp.User):
                 Parsed user object.
         """
         username = "{}#{}".format(user.name, user.discriminator)
-        real_name = getattr(user, "nick", None) or user.name
+        real_name = user.display_name
         # Avatar URL is an Asset object, URL only available via __str__.
         avatar = str(user.avatar_url) if user.avatar_url else None
+        link = "https://discord.com/users/{}".format(user.id)
         return cls(id_=user.id,
                    plug=discord_,
                    username=username,
                    real_name=real_name,
                    avatar=avatar,
+                   link=link,
                    raw=user)
 
 
@@ -117,15 +127,15 @@ class DiscordRichText(immp.RichText):
         return "#{}".format(discord_._client.get_channel(int(match.group(1))).name)
 
     @classmethod
-    def from_markdown(cls, discord_, text, channel=None):
+    def from_message(cls, discord_, message, channel=None):
         """
-        Convert a string of Markdown into a :class:`.RichText`.
+        Convert a string of Markdown from a Discord message into a :class:`.RichText`.
 
         Args:
             discord (.DiscordPlug):
                 Related plug instance that provides the text.
-            text (str):
-                Markdown formatted text.
+            message (discord.Message):
+                Containing message object, in order to resolve mentions.
             channel (.Channel):
                 Related channel, used to retrieve mentioned users as members.
 
@@ -133,6 +143,7 @@ class DiscordRichText(immp.RichText):
             .DiscordRichText:
                 Parsed rich text container.
         """
+        text = message.content
         changes = defaultdict(dict)
         plain = ""
         done = False
@@ -170,13 +181,13 @@ class DiscordRichText(immp.RichText):
                 changes[len(plain)]["pre"] = True
                 changes[len(plain + pre)]["pre"] = False
                 plain += pre
-        dc_channel = discord_._get_channel(channel)
-        if isinstance(dc_channel, discord.TextChannel):
-            getter = dc_channel.guild.get_member
-        else:
-            getter = discord_._client.get_user
+        mentioned = {user.id: user for user in message.mentions}
         for match in cls._mention_regex.finditer(plain):
-            user = getter(int(match.group(1)))
+            id_ = int(match.group(1))
+            if id_ in mentioned:
+                user = mentioned[id_]
+            else:
+                user = mentioned[id_] = discord_._client.get_user(id_)
             if user:
                 changes[match.start()]["mention"] = DiscordUser.from_user(discord_, user)
                 changes[match.end()]["mention"] = None
@@ -191,7 +202,7 @@ class DiscordRichText(immp.RichText):
                 continue
             if formatting.get("mention"):
                 user = formatting["mention"]
-                part = "@{}".format(user.username or user.real_name)
+                part = "@{}".format(user.real_name or user.username)
             else:
                 part = emojize(plain[start:end], use_aliases=True)
                 # Strip Discord channel/emoji tags, replace with a plain text representation.
@@ -319,7 +330,7 @@ class DiscordMessage(immp.Message):
         user = DiscordUser.from_user(discord_, message.author)
         attachments = []
         if message.content:
-            text = DiscordRichText.from_markdown(discord_, message.content, channel)
+            text = DiscordRichText.from_message(discord_, message, channel)
         for attach in message.attachments:
             if attach.filename.endswith((".jpg", ".png", ".gif")):
                 type_ = immp.File.Type.image
@@ -454,7 +465,9 @@ class DiscordPlug(immp.HTTPOpenable, immp.Plug):
     async def start(self):
         await super().start()
         log.debug("Starting client")
-        self._client = DiscordClient(self)
+        intents = discord.Intents.default()
+        intents.members = self.config["members"]
+        self._client = DiscordClient(self, intents=intents)
         self._task = ensure_future(self._client.start(self.config["token"], bot=self.config["bot"]))
         async with self._starting:
             # Block until the client is ready.
